function [t, y] = eul_imp(funz,jacf,tspan,y0,h)
% 
% Funzione che calcola la soluzione di un'equazione differenziale 
% con il metodo di Eulero implicito.
% INPUT:
% funz	stringa contenente il nome del file che definisce
%		l'equazione differenziale
% jacf	stringa contenente il nome del file che definisce
%		lo jacobiano della funzione
% tspan [t0,tf]		istante di tempo iniziale,istante di tempo finale
% y0 		condizione iniziale
% h 		passo temporale
% OUTPUT
% t 		vettore contenente un insieme di punti
%  		interni all'intervallo di tempo considerato
% y		vettore contenete la soluzione nei punti del vettore t
%
t0=tspan(1);
tf=tspan(2);
t= t0:h:tf;
 N=length(t);
 I= eye(length(y0));
 epsilon =1e-5; 
 y(:,1)=y0;
 for n=1:N-1
   y(:,n+1) =y(:,n);
 	A=I-h*feval(jacf,t(n+1),y(:,n+1));
 	b=y(:,n+1) -y(:,n) -h*feval(funz,t(n+1),y(:,n+1));
 	u= A\b;
 	y(:,n+1)=y(:,n+1) - u;
 	cont=1;
 	while(norm(u,'inf') >epsilon) & (cont<100)
  	 A=I-h*feval(jacf,t(n+1),y(:,n+1));
    b=y(:,n+1) -y(:,n) -h*feval(funz,t(n+1),y(:,n+1));
  	 u= A\b;
  	 y(:,n+1)=y(:,n+1) - u;
  	 cont=cont+1;
 	end
 if cont ==100
   disp(['In' num2str(t(n)) ' non si raggiunge '])
   disp('la approssimazione desiderata')
   disp('per la soluzione')
 end
end
