function flame(fname)
% FLAME  A stiff ordinary differential equation.
% A ball of fire grows until its radius is just large enough that all of
% the oxygen available through the surface is consumed by combustion in
% the interior. 
% The problem becomes stiff as the radius approaches its limiting value.


m = 30;
[rho,theta] = ndgrid((0:m)'/m, pi*(-m:m)/m);
x = rho.*sin(theta);
y = rho.*cos(theta);
r0 = .01;
[t,r] = ode23(fname,[0 2/r0],r0,odeset('reltol',1.e-4));
figure
plot(t,r,'o')
size(t)
figure
shg
set(gcf,'double','on','color','black')
set(gca,'color','black')
z = 1-rho/r0;
p = pcolor(x,y,z);
shading interp
colormap(hot)
axis square
axis off
s = title(sprintf('t = %8.2f   r = %10.6f',0,r0),'fontsize',16);
set(s,'color','white');
for k = 1:length(t);
   z = max(0,1-rho/r(k));
   set(p,'cdata',z)
   set(s,'string',sprintf('t = %8.1f   r = %10.6f',t(k),r(k)));
   drawnow
end


uicontrol('string','close','callback','close(gcf)')
